Deep QEP and Deep Sigma Point Processes
========================================

Deep QEP and Deep Sigma Point Processes are hierarchical models
where each layer is a q-exponential process.

Deep QEP
----------

- `Standard Deep QEP regression <./Deep_QExponential_Processes.ipynb>`_
- `Multitask Deep QEP regression <./DQEP_Multitask_Regression.ipynb>`_

Deep Sigma Point Processes (DSPP)
---------------------------------------

- `DSPP regression <./Deep_Sigma_Point_Processes.ipynb>`_
- `Multitask DSPP regression <./DQEP_Multitask_Regression.ipynb>`_

.. toctree::
   :glob:
   :maxdepth: 1
   :hidden:

   Deep_QExponential_Processes.ipynb
   Deep_Sigma_Point_Processes.ipynb
   DQEP_Multitask_Regression.ipynb
